@@ -56,6 +56,7 @@
 #include "MicrobEalNotificationBox.h"
 #include "MicrobEalNotificationButton.h"
 #include "MicrobEalNotification.h"
+#include "MicrobEalSidebarExternal.h"
 #include "gtkmozembed_internal2.h"
 
 NS_GENERIC_FACTORY_CONSTRUCTOR(EmbedXulAppInfo)
@@ -65,8 +66,11 @@ NS_GENERIC_FACTORY_CONSTRUCTOR(MicrobEalNotificationBox)
 NS_GENERIC_FACTORY_CONSTRUCTOR(MicrobEalNotificationButton)
 NS_GENERIC_FACTORY_CONSTRUCTOR(MicrobEalNotification)
 NS_GENERIC_FACTORY_CONSTRUCTOR(MicrobEalDownloadMgr)
+NS_GENERIC_FACTORY_CONSTRUCTOR(MicrobEalSidebarExternal)
 NS_GENERIC_FACTORY_CONSTRUCTOR_INIT(MicrobEalCertificate, Init)
 
+NS_DECL_CLASSINFO(MicrobEalSidebarExternal)
+
 static const nsModuleComponentInfo microbEalAppComps[] =
 {
   {
@@ -111,6 +115,19 @@ static const nsModuleComponentInfo microbEalAppComps[] =
     MICROBEAL_DOWNLOADMGR_CID,
     NS_IHELPERAPPLAUNCHERDLG_CONTRACTID,
     MicrobEalDownloadMgrConstructor
+  },
+  {
+    MICROB_EAL_SIDEBAR_EXT_DESCRIPTION,
+    MICROB_EAL_SIDEBAR_EXT_CID,
+    NS_SIDEBAR_CONTRACTID,
+    MicrobEalSidebarExternalConstructor,
+    MicrobEalSidebarExternal::RegisterSelf,
+    MicrobEalSidebarExternal::UnregisterSelf,
+    nsnull,
+    NS_CI_INTERFACE_GETTER_NAME(MicrobEalSidebarExternal),
+    nsnull,
+    &NS_CLASSINFO_NAME(MicrobEalSidebarExternal),
+    nsIClassInfo::DOM_OBJECT
   }
 };
 
